@@ -17,7 +17,7 @@
  *
  * Needs to include: magic.h database.h
  *
- * rcsid $Header: /usr/cvsroot/magic-8.0/drc/drc.h,v 1.4 2009/09/11 15:47:09 tim Exp $
+ * rcsid $Header: /usr/cvsroot/magic-8.0/drc/drc.h,v 1.6 2010/09/20 21:13:22 tim Exp $
  */
 
 #ifndef _DRC_H
@@ -50,18 +50,24 @@ typedef struct drccookie
  * DRC_FORWARD:		Rule applies from left to right (or bottom to top).
  * DRC_REVERSE:		Rule applies from right to left (or top to bottom).
  * DRC_BOTHCORNERS:	Must make corner extensions in both directions.
+ * DRC_OUTSIDE:		Rule applies only to the outside edge of the rule area.
+ * DRC_TRIGGER:		Violation of rule triggers a secondary rule.
+ *
+ * All other flags denote special DRC rules that do not use the standard 4-way
+ * edge processing.
  */
 
-#define		DRC_FORWARD		0x0
-#define		DRC_REVERSE		0x1
-#define		DRC_BOTHCORNERS		0x2
-#define		DRC_TRIGGER		0x4
-#define		DRC_AREA		0x8
-#define		DRC_MAXWIDTH		0x10
-#define		DRC_BENDS		0x20
+#define		DRC_FORWARD		0x00
+#define		DRC_REVERSE		0x01
+#define		DRC_BOTHCORNERS		0x02
+#define		DRC_TRIGGER		0x04
+#define		DRC_BENDS		0x08
+#define		DRC_OUTSIDE		0x08	// Note: Shared with DRC_BENDS
+#define		DRC_AREA		0x10
+#define		DRC_MAXWIDTH		0x20
 #define		DRC_RECTSIZE		0x40
 #define		DRC_ANGLES		0x80
-#define 	DRC_WEIRD_ONES		(DRC_AREA|DRC_MAXWIDTH|DRC_RECTSIZE|DRC_ANGLES)
+#define 	DRC_NONSTANDARD		(DRC_AREA|DRC_MAXWIDTH|DRC_RECTSIZE|DRC_ANGLES)
 
 #define	DRC_PENDING			0
 #define DRC_UNPROCESSED 		CLIENTDEFAULT
@@ -100,6 +106,8 @@ struct drcClientData
     int		  dCD_radial;		/* Radial check for corner extensions */
     DRCCookie	* dCD_cptr;		/* Rule being checked. */
     Rect	* dCD_constraint;	/* Constraint area from rule. */
+    Rect	* dCD_rlist;		/* Multiple constraints for triggered rules */
+    int		  dCD_entries;		/* Number of constraints for triggered rules */
     void	(* dCD_function)(); 	/* Function to call for each
 				    	 * error found. */
     ClientData	dCD_clientData;		/* Parameter for dCD_function */
@@ -164,10 +172,24 @@ typedef struct drcstyle
     int			DRCScaleFactorD; /* Multiply dist by this to get magic units */
     int			DRCTechHalo;	/* largest action distance of design rules */
     int			DRCStepSize;	/* chunk size for decomposing large areas */
+    char		DRCFlags;	/* Option flags */
     drcWhyList		*DRCWhyList;
     PaintResultType	DRCPaintTable[NP][NT][NT];
 } DRCStyle;
 
+/* flag values used by DRCFlags */
+
+/*  DRC_FLAGS_WIDEWIDTH_NONINCLUSIVE:  If set, indicates that the ruleset	*/
+/*  defines "wide" as material of MORE THAN the given DRC rule width value, as	*/
+/*  opposed to the default behavior, which is to define "wide" as material of	*/
+/*  AT LEAST the given DRC rule width value.					*/
+
+/* (Note that at least for now, there is no similar flag for "maxwidth" rules,	*/
+/* which are always interpreted as inclusive, meaning that material of the	*/
+/* exact width of the DRC rule width value is legal.)				*/
+
+#define DRC_FLAGS_WIDEWIDTH_NONINCLUSIVE  0x01
+
 /* Things shared between DRC functions, but not used by the
  * outside world:
  */
@@ -192,7 +214,7 @@ extern int DRCTechHalo;		/* Current halo being used */
 extern int DRCStepSize;		/* Current step size being used */
 extern DRCPendingCookie * DRCPendingRoot;
 
-extern u_char DRCBackGround;	/* global flag to enable/disable
+extern unsigned char DRCBackGround;	/* global flag to enable/disable
 				 * continuous DRC
 			     	 */
 extern bool DRCEuclidean;	/* global flag to enable/disable
