@@ -211,7 +211,8 @@ Exttospice_Init(interp)
 #define EXTTOSPC_BLACKBOX	11
 #define EXTTOSPC_RENUMBER	12
 #define EXTTOSPC_MERGENAMES	13
-#define EXTTOSPC_HELP		14
+#define EXTTOSPC_LVS		14
+#define EXTTOSPC_HELP		15
 
 void
 CmdExtToSpice(w, cmd)
@@ -262,6 +263,7 @@ CmdExtToSpice(w, cmd)
 	"renumber [on|off]	on = number instances X1, X2, etc.\n"
 	"			off = keep instance ID names",
 	"global [on|off]	on = merge unconnected global nets by name",
+	"lvs    		apply typical default settings for LVS",
 	"help			print help information",
 	NULL
     };
@@ -418,6 +420,29 @@ CmdExtToSpice(w, cmd)
 		esMergeNames = FALSE;
 	    break;
 
+	case EXTTOSPC_LVS:
+	    /* Apply default command settings for LVS */
+	    /* hierarchy = on		*/
+	    /* format    = ngspice	*/
+	    /* cthresh   = infinite	*/
+	    /* rthresh   = infinite	*/
+	    /* renumber  = off		*/
+	    /* scale     = off		*/
+	    /* blackbox  = on		*/
+	    /* global    = off		*/
+	    /* subcircuit top = auto	*/
+
+	    esDoHierarchy = TRUE;
+	    esFormat = NGSPICE;
+	    LocCapThreshold = (EFCapValue)INFINITE_THRESHOLD_F;
+	    LocResistThreshold = INFINITE_THRESHOLD;
+	    esDoRenumber = FALSE;
+	    esScale = 0.0;
+	    esDoBlackBox = TRUE;
+	    esMergeNames = FALSE;
+	    esDoSubckt = 2;
+	    break;
+
 	case EXTTOSPC_SUBCIRCUITS:
 	    if (cmd->tx_argc == 2)
 	    {
@@ -489,7 +514,7 @@ CmdExtToSpice(w, cmd)
 	    if (idx < 0)
 	    {
 		Tcl_SetResult(magicinterp, "Bad format type.  Formats are:"
-			"spice2, spice3, and hspice.", NULL);
+			"spice2, spice3, hspice, and ngspice.", NULL);
 		return;
 	    }
 	    else
@@ -1344,6 +1369,10 @@ subcktVisit(use, hierName, is_top)
     /* Retain instance name unless esDoRenumber is set, or format is Spice2 */
     if (use->use_id == NULL || esDoRenumber == TRUE || esFormat == SPICE2)
     {
+	/* NOTE:  This really needs to update subcktNameTable so that	*/
+	/* it tracks between instance names and node names, when using	*/
+	/* HSPICE format + esDoRenumber.				*/
+
 	fprintf(esSpiceF, "X%d", esSbckNum++);
 	tchars = 5;
     }
@@ -2145,6 +2174,7 @@ spcdevVisit(dev, hierName, scale, trans)
     {
 	case DEV_SUBCKT:
 	case DEV_RSUBCKT:
+	case DEV_CSUBCKT:
 	case DEV_MSUBCKT:
 	    break;
 	case DEV_DIODE:
@@ -2234,6 +2264,7 @@ spcdevVisit(dev, hierName, scale, trans)
 	    break;
 	case DEV_SUBCKT:
 	case DEV_RSUBCKT:
+	case DEV_CSUBCKT:
 	case DEV_MSUBCKT:
 	    devchar = 'X';
 	    break;
@@ -2270,6 +2301,7 @@ spcdevVisit(dev, hierName, scale, trans)
 		break;
 	    case DEV_SUBCKT:
 	    case DEV_RSUBCKT:
+	    case DEV_CSUBCKT:
 	    case DEV_MSUBCKT:
 		fprintf(esSpiceF, "%d", esSbckNum++);
 		break;
@@ -2317,6 +2349,7 @@ spcdevVisit(dev, hierName, scale, trans)
 	    /* Drop through to below (no break statement) */
 
 	case DEV_SUBCKT:
+	case DEV_CSUBCKT:
 
 	    /* Subcircuit is "Xnnn gate [source [drain [sub]]]"		*/
 	    /* Subcircuit .subckt record must be ordered to match!	*/
@@ -3239,10 +3272,10 @@ char *efHNSprintfPrefix(hierName, str)
  * nodeHspiceName --
  *
  * Convert the hierarchical node name used in Berkeley spice 
- * to a name understodd by hspice and hopefully by the user.
+ * to a name understood by hspice and hopefully by the user.
  *
  * Results:
- *	A somewhat meaningfull node name
+ *	A somewhat meaningful node name
  *
  * Side effects:
  *	Mucks with the hash table above.
@@ -3277,7 +3310,7 @@ int nodeHspiceName(s)
     sf = p + 1;
 
     /* 
-     * look up prefix in the hash table ad create it if doesnt exist 
+     * look up prefix in the hash table and create it if doesn't exist 
      */
     if ((he = HashLookOnly(&subcktNameTable, s)) == NULL)
     {
@@ -3488,6 +3521,7 @@ parallelDevs(f1, f2)
 
 	case DEV_SUBCKT:
 	case DEV_RSUBCKT:
+	case DEV_CSUBCKT:
 	    break;
     }
     return NOT_PARALLEL;
@@ -3665,6 +3699,7 @@ mergeThem:
 		    else
 		        m = esFMult[cfp->esFMIndex] + (fp->l / cfp->l);
 		    break;
+		case DEV_CSUBCKT:
 		case DEV_CAP:
 		case DEV_CAPREV:
 		    if (fp->dev->dev_type == esNoModelType)
