@@ -183,8 +183,12 @@ EFGetLengthAndWidth(dev, lptr, wptr)
 	case DEV_SUBCKT:
 	case DEV_MSUBCKT:
 	case DEV_RSUBCKT:
+	case DEV_CSUBCKT:
 	case DEV_DIODE:
+	case DEV_PDIODE:
+	case DEV_NDIODE:
 	case DEV_CAP:
+	case DEV_CAPREV:
 	case DEV_RES:
 	    l = dev->dev_length;
 	    w = dev->dev_width;
@@ -675,8 +679,16 @@ EFVisitNodes(nodeProc, cdata)
 	res = EFNodeResist(node);
 	cap = node->efnode_cap;
 	hierName = (HierName *) node->efnode_name->efnn_hier;
-	if (node->efnode_flags & EF_SUBS_NODE)
-	    cap = 0;
+	if (EFCompat)
+	{
+	    if (EFHNIsGND(hierName))
+		cap = 0;
+	}
+	else
+	{
+	    if (node->efnode_flags & EF_SUBS_NODE)
+		cap = 0;
+	}
 	if (efWatchNodes)
 	{
 	    for (nn = node->efnode_name; nn; nn = nn->efnn_next)
